@@ -46,7 +46,6 @@ static struct {
 	{ GTHUMB_STOCK_EDIT_IMAGE,          edit_image_24_rgba,          NULL },
 	{ GTHUMB_STOCK_FILM,                film_16_rgba,                NULL },
 	{ GTHUMB_STOCK_FLIP,                flip_24_rgba,                flip_16_rgba },
-	{ GTHUMB_STOCK_FULLSCREEN,          fullscreen_24_rgba,          fullscreen_16_rgba },
 	{ GTHUMB_STOCK_HISTOGRAM,           histogram_22_rgba,           histogram_16_rgba },
 	{ GTHUMB_STOCK_HUE_SATURATION,      hue_saturation_22_rgba,      hue_saturation_16_rgba },
 	{ GTHUMB_STOCK_IMAGE,               image_24_rgba,               NULL },
@@ -55,7 +54,6 @@ static struct {
 	{ GTHUMB_STOCK_LEVELS,              levels_22_rgba,              levels_16_rgba },
 	{ GTHUMB_STOCK_MIRROR,              mirror_24_rgba,              mirror_16_rgba },
 	{ GTHUMB_STOCK_NEXT_IMAGE,          next_image_24_rgba,          NULL },
-	{ GTHUMB_STOCK_NORMAL_VIEW,         exit_fullscreen_24_rgba,     NULL },
 	{ GTHUMB_STOCK_POSTERIZE,           posterize_22_rgba,           posterize_16_rgba },
 	{ GTHUMB_STOCK_PREVIOUS_IMAGE,      prev_image_24_rgba,          NULL },
 	{ GTHUMB_STOCK_REDUCE_COLORS,       reduce_colors_16_rgba,       NULL },
