@@ -36,6 +36,7 @@
 #include "image-loader.h"
 #include "gthumb-marshal.h"
 #include "file-utils.h"
+#include "glib-utils.h"
 
 
 #define REFRESH_RATE 5
@@ -71,6 +72,7 @@ struct _ImageLoaderPrivateData {
 	gboolean              emit_signal;
 
 	guint                 check_id;
+	guint                 idle_id;
 
 	GThread              *thread;
 
@@ -151,7 +153,8 @@ image_loader_finalize__step2 (GObject *object)
 static void image_loader_stop_common (ImageLoader *il,
 				      DoneFunc     done_func,
 				      gpointer     done_func_data,
-				      gboolean     emit_sig);
+				      gboolean     emit_sig,
+				      gboolean     use_idle_cb);
 
 
 static void 
@@ -165,10 +168,16 @@ image_loader_finalize (GObject *object)
   
         il = IMAGE_LOADER (object);
 	priv = il->priv;
+
+	if (priv->idle_id != 0) {
+		g_source_remove (priv->idle_id);
+		priv->idle_id = 0;
+	}
 	
 	image_loader_stop_common (il, 
 				  (DoneFunc) image_loader_finalize__step2, 
 				  object,
+				  FALSE,
 				  FALSE);
 }
 
@@ -246,6 +255,7 @@ image_loader_init (ImageLoader *il)
 	priv->done_func_data = NULL;
 
 	priv->check_id = 0;
+	priv->idle_id = 0;
 
 	priv->yes_or_no = g_mutex_new ();
 
@@ -338,13 +348,8 @@ image_loader_set_path (ImageLoader *il,
 		gnome_vfs_uri_unref (priv->uri);
 		priv->uri = NULL;
 	}
-
-	if (path != NULL) {
-		char *escaped_path;
-		escaped_path = gnome_vfs_escape_path_string (path);
-		priv->uri = gnome_vfs_uri_new (escaped_path);
-		g_free (escaped_path);
-	}
+	if (path != NULL) 
+		priv->uri = new_uri_from_path (path);
 
 	g_mutex_unlock (priv->yes_or_no);
 }
@@ -391,8 +396,11 @@ image_loader_set_pixbuf (ImageLoader *il,
 		priv->pixbuf = NULL;
 	}
 
-	if (pixbuf != NULL) 
-		priv->pixbuf = gdk_pixbuf_copy (pixbuf);
+	if (pixbuf != NULL) {
+		g_object_ref (pixbuf);
+		priv->pixbuf = pixbuf;
+		/*priv->pixbuf = gdk_pixbuf_copy (pixbuf);*/
+	}
 
 	g_mutex_unlock (priv->yes_or_no);
 }
@@ -431,8 +439,11 @@ image_loader_sync_pixbuf (ImageLoader *il)
 		g_object_unref (priv->pixbuf);
 		priv->pixbuf = NULL;
 	}
-	if (pixbuf != NULL) 
-		priv->pixbuf = gdk_pixbuf_copy (pixbuf);
+	if (pixbuf != NULL) {
+		g_object_ref (pixbuf);
+		priv->pixbuf = pixbuf;
+		/*priv->pixbuf = gdk_pixbuf_copy (pixbuf);*/
+	}
 	g_object_unref (pixbuf);
 
 	g_mutex_unlock (priv->yes_or_no);
@@ -479,8 +490,11 @@ image_loader_sync_pixbuf_from_loader (ImageLoader     *il,
 		g_object_unref (priv->pixbuf);
 		priv->pixbuf = NULL;
 	}
-	if (pixbuf != NULL)
-		priv->pixbuf = gdk_pixbuf_copy (pixbuf);
+	if (pixbuf != NULL) {
+		g_object_ref (pixbuf);
+		priv->pixbuf = pixbuf;
+		/*priv->pixbuf = gdk_pixbuf_copy (pixbuf);*/
+	}
 	g_object_unref (pixbuf);
 
 	g_mutex_unlock (priv->yes_or_no);
@@ -499,6 +513,7 @@ image_loader_interrupted (ImageLoader *il)
 	image_loader_stop_common (il, 
 				  priv->done_func, 
 				  priv->done_func_data, 
+				  TRUE,
 				  TRUE);
 }
 
@@ -512,7 +527,7 @@ image_loader_done (ImageLoader *il)
 	priv->error = FALSE;
 	g_mutex_unlock (priv->yes_or_no);
 
-	image_loader_stop_common (il, NULL, NULL, TRUE);
+	image_loader_stop_common (il, NULL, NULL, TRUE, TRUE);
 }
 
 
@@ -525,7 +540,7 @@ image_loader_error (ImageLoader *il)
 	priv->error = TRUE;
 	g_mutex_unlock (priv->yes_or_no);
 
-	image_loader_stop_common (il, NULL, NULL, TRUE);
+	image_loader_stop_common (il, NULL, NULL, TRUE, TRUE);
 }
 
 
@@ -565,7 +580,7 @@ load_image_thread (void *thread_data)
 			if (priv->loader != NULL) 
 				animation = (*priv->loader) (path, &error, priv->loader_data);
 			else {
-				if (image_is_gif (path))
+				if (image_is_gif__accurate (path))
 					animation = gdk_pixbuf_animation_new_from_file (path, &error);
 				else {
 					GdkPixbuf *pixbuf;
@@ -606,7 +621,8 @@ load_image_thread (void *thread_data)
 
 
 static void
-image_loader_stop__final_step (ImageLoader *il) 
+image_loader_stop__final_step (ImageLoader *il,
+			       gboolean     use_idle_cb) 
 {
 	ImageLoaderPrivateData *priv = il->priv;
 	DoneFunc                done_func = priv->done_func;
@@ -622,8 +638,12 @@ image_loader_stop__final_step (ImageLoader *il)
 	priv->loading = FALSE;
 	
 	priv->done_func = NULL;
-	if (done_func != NULL)
-		(*done_func) (priv->done_func_data);
+	if (done_func != NULL) {
+		IdleCall* call = idle_call_new (done_func, priv->done_func_data);
+		if (priv->idle_id != 0) 
+			g_source_remove (priv->idle_id);
+		priv->idle_id = idle_call_exec (call, use_idle_cb);
+	}
 	
 	if (! priv->emit_signal || priv->interrupted) {
 		priv->interrupted = FALSE;
@@ -641,7 +661,7 @@ image_loader_stop__final_step (ImageLoader *il)
 }
 
 
-static int
+static gboolean
 check_thread (gpointer data)
 {
 	ImageLoader            *il = data;
@@ -748,9 +768,10 @@ image_loader_start__step2 (ImageLoader *il)
 				       uri_list,
 				       (GNOME_VFS_FILE_INFO_DEFAULT
 					| GNOME_VFS_FILE_INFO_FOLLOW_LINKS),
-				       GNOME_VFS_PRIORITY_DEFAULT,
+				       priv->priority,
 				       get_file_info_cb,
 				       il);
+
 	{
 		GList *scan;
 		for (scan = uri_list; scan; scan = scan->next) 
@@ -776,7 +797,11 @@ image_loader_start (ImageLoader *il)
 	}
 	g_mutex_unlock (priv->yes_or_no);
 
-	image_loader_stop_common (il, (DoneFunc) image_loader_start__step2, il, FALSE);
+	image_loader_stop_common (il, 
+				  (DoneFunc) image_loader_start__step2, 
+				  il, 
+				  FALSE,
+				  TRUE);
 }
 
 
@@ -804,7 +829,8 @@ static void
 image_loader_stop_common (ImageLoader *il,
 			  DoneFunc     done_func,
 			  gpointer     done_func_data,
-			  gboolean     emit_sig)
+			  gboolean     emit_sig,
+			  gboolean     use_idle_cb)
 {
 	ImageLoaderPrivateData *priv;
 
@@ -821,7 +847,7 @@ image_loader_stop_common (ImageLoader *il,
 		gnome_vfs_async_close (priv->info_handle, close_info_cb, il);
 
 	priv->info_handle = NULL;
-	image_loader_stop__final_step (il);
+	image_loader_stop__final_step (il, use_idle_cb);
 }
 
 
@@ -831,7 +857,6 @@ image_loader_stop (ImageLoader *il,
 		   gpointer     done_func_data)
 {
 	ImageLoaderPrivateData *priv;
-	/*gboolean                emit_sig;*/
 
 	g_return_if_fail (il != NULL);
 
@@ -847,13 +872,11 @@ image_loader_stop (ImageLoader *il,
 		priv->done_func = done_func;
 		priv->done_func_data = done_func_data;
 	} else
-		image_loader_stop_common (il, done_func, done_func_data, FALSE);
-
-	/* FIXME: emit a signal only if there is an operation to stop */
-	/*
-	  emit_sig = (priv->info_handle != NULL);
-	  image_loader_stop_common (il, done_func, done_func_data, emit_sig);
-	*/
+		image_loader_stop_common (il, 
+					  done_func, 
+					  done_func_data, 
+					  FALSE, 
+					  TRUE);
 }
 
 
@@ -872,7 +895,7 @@ image_loader_stop_with_error (ImageLoader *il,
 	priv->error = TRUE;
 	g_mutex_unlock (priv->yes_or_no);
 
-	image_loader_stop_common (il, done_func, done_func_data, TRUE);
+	image_loader_stop_common (il, done_func, done_func_data, TRUE, TRUE);
 }
 
 
