@@ -3,7 +3,7 @@
 /*
  *  GThumb
  *
- *  Copyright (C) 2001 The Free Software Foundation, Inc.
+ *  Copyright (C) 2001, 2003 Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
  */
 
 #include <config.h>
+#include <math.h>
 #include <sys/types.h>
 #include <string.h>
 #include <unistd.h>
@@ -29,7 +30,7 @@
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <glade/glade.h>
 
-#include "gthumb-window.h"
+#include "gth-window.h"
 #include "pixbuf-utils.h"
 #include "gconf-utils.h"
 #include "preferences.h"
@@ -48,7 +49,7 @@ enum {
 
 
 typedef struct {
-	GThumbWindow *window;
+	GthWindow    *window;
 	ImageViewer  *viewer;
 	GladeXML     *gui;
 
@@ -113,21 +114,19 @@ ok_cb (GtkWidget  *widget,
 		d_height = d_height / 100.0 * data->height;
 	} 
 
-	width  = (int) d_width;
-	height = (int) d_height;
-
+	width  = MAX (2, (int) d_width);
+	height = MAX (2, (int) d_height);
 	new_pixbuf = gdk_pixbuf_scale_simple (orig_pixbuf,
 					      width,
 					      height,
 					      high_quality ? GDK_INTERP_BILINEAR : GDK_INTERP_NEAREST);
 
-	image_viewer_set_pixbuf (data->viewer, new_pixbuf);
+	gth_window_set_image_pixbuf (data->window, new_pixbuf);
+	gth_window_set_image_modified (data->window, TRUE);
 
 	g_object_unref (orig_pixbuf);
 	g_object_unref (new_pixbuf);
 
-	window_image_set_modified (data->window, TRUE);
-
 	gtk_widget_destroy (data->dialog);
 }
 
@@ -175,7 +174,7 @@ h_spinbutton_value_changed (GtkSpinButton *button,
 		if (data->percentage)
 			width = height;
 		else
-			width = height * data->ratio;
+			width = floor (height * data->ratio + 0.5);
 
 		g_signal_handlers_block_by_func (data->s_new_width_spinbutton,
 						 w_spinbutton_value_changed,
@@ -208,7 +207,7 @@ w_spinbutton_value_changed (GtkSpinButton *button,
 		if (data->percentage)
 			height = width;
 		else
-			height = width / data->ratio;
+			height = floor (width / data->ratio + 0.5);
 
 		g_signal_handlers_block_by_func (data->s_new_height_spinbutton,
 						 h_spinbutton_value_changed,
@@ -276,7 +275,7 @@ unit_changed (GtkOptionMenu *option_menu,
 
 
 void
-dlg_scale_image (GThumbWindow *window)
+dlg_scale_image (GthWindow *window)
 {
 	DialogData *data;
 	GtkWidget  *ok_button;
@@ -311,7 +310,7 @@ dlg_scale_image (GThumbWindow *window)
 	ok_button = glade_xml_get_widget (data->gui, "s_ok_button");
 	cancel_button = glade_xml_get_widget (data->gui, "s_cancel_button");
 
-	data->viewer = IMAGE_VIEWER (window->viewer);
+	data->viewer = gth_window_get_image_viewer (window);
 
 	pixbuf = image_viewer_get_current_pixbuf (data->viewer);
 
@@ -333,7 +332,7 @@ dlg_scale_image (GThumbWindow *window)
 
 	/**/
 
-	unit = eel_gconf_get_string (PREF_SCALE_UNIT);
+	unit = eel_gconf_get_string (PREF_SCALE_UNIT, "pixels");
 
 	data->percentage = strcmp (unit, "percentage") == 0;
 	if (data->percentage) {
@@ -349,9 +348,9 @@ dlg_scale_image (GThumbWindow *window)
 	g_free (unit);
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->s_keep_ratio_checkbutton),
-				      eel_gconf_get_boolean (PREF_SCALE_KEEP_RATIO));
+				      eel_gconf_get_boolean (PREF_SCALE_KEEP_RATIO, TRUE));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->s_high_quality_checkbutton),
-				      eel_gconf_get_boolean (PREF_SCALE_HIGH_QUALITY));
+				      eel_gconf_get_boolean (PREF_SCALE_HIGH_QUALITY, TRUE));
 
 	/* Set the signals handlers. */
 	
@@ -393,7 +392,7 @@ dlg_scale_image (GThumbWindow *window)
 	/* Run dialog. */
 
 	gtk_window_set_transient_for (GTK_WINDOW (data->dialog),
-				      GTK_WINDOW (window->app));
+				      GTK_WINDOW (window));
 	gtk_widget_show (data->dialog);
 
 	update_ratio (data);
